aboutsummaryrefslogtreecommitdiff
path: root/src/dogecoin-fees.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/dogecoin-fees.cpp')
-rw-r--r--src/dogecoin-fees.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/dogecoin-fees.cpp b/src/dogecoin-fees.cpp
index 830d4ba23..094dfeec7 100644
--- a/src/dogecoin-fees.cpp
+++ b/src/dogecoin-fees.cpp
@@ -1,4 +1,4 @@
-// Copyright (c) 2021 The Dogecoin Core developers
+// Copyright (c) 2021 The Discoin Core developers
// Distributed under the MIT software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.
@@ -18,23 +18,23 @@
#endif
#ifdef ENABLE_WALLET
-//mlumin 5/2021: walletfees, all attached to GetDogecoinWalletFeeRate which is just the newly exposed ::minWalletTxFee
-CAmount GetDogecoinWalletFee(size_t nBytes_)
+//mlumin 5/2021: walletfees, all attached to GetDiscoinWalletFeeRate which is just the newly exposed ::minWalletTxFee
+CAmount GetDiscoinWalletFee(size_t nBytes_)
{
//mlumin: super simple fee calc for discoin
- CAmount nFee=GetDogecoinWalletFeeRate().GetFee(nBytes_);
+ CAmount nFee=GetDiscoinWalletFeeRate().GetFee(nBytes_);
}
//mlumin 5/2021: Establish a wallet rate of n koinu per kb.
//mlumin: this is somewhat redundant to the globally exposed ::minWalletTxFee, but honestly I'd like to have both the rate and amount (with size) here
-CFeeRate GetDogecoinWalletFeeRate()
+CFeeRate GetDiscoinWalletFeeRate()
{
//mlumin 5/2021: currently 1x COIN or 1 discoin or 100,000,000 koinu
return ::minWalletTxFeeRate;
}
#endif
-CAmount GetDogecoinMinRelayFee(const CTransaction& tx, unsigned int nBytes, bool fAllowFree)
+CAmount GetDiscoinMinRelayFee(const CTransaction& tx, unsigned int nBytes, bool fAllowFree)
{
{
LOCK(mempool.cs);
@@ -47,7 +47,7 @@ CAmount GetDogecoinMinRelayFee(const CTransaction& tx, unsigned int nBytes, bool
}
CAmount nMinFee = ::minRelayTxFeeRate.GetRelayFee(nBytes);
- nMinFee += GetDogecoinDustFee(tx.vout, ::minRelayTxFeeRate);
+ nMinFee += GetDiscoinDustFee(tx.vout, ::minRelayTxFeeRate);
if (fAllowFree)
{
@@ -64,7 +64,7 @@ CAmount GetDogecoinMinRelayFee(const CTransaction& tx, unsigned int nBytes, bool
return nMinFee;
}
-CAmount GetDogecoinDustFee(const std::vector<CTxOut> &vout, CFeeRate &baseFeeRate) {
+CAmount GetDiscoinDustFee(const std::vector<CTxOut> &vout, CFeeRate &baseFeeRate) {
CAmount nFee = 0;
// To limit dust spam, add base fee for each output less than a COIN